==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-galego.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","O seu nome");
define("_OK","Aceptar");
define("_COMMENT","comentario");
define("_CONFIGURE","Configurar");
define("_LOGINCREATE","Entrar/Crear Conta");
define("_THRESHOLD","Puntos");
define("_NOCOMMENTS","Sen comentarios");
define("_NESTED","Aniados");
define("_FLAT","Plano");
define("_THREAD","Fo");
define("_OLDEST","Antigos Primeiro");
define("_NEWEST","Novos Primeiro");
define("_HIGHEST","Maior Puntuacin Primeiro");
define("_COMMENTSWARNING","Os comentarios son propiedade de quen os enviou. Non somos responsables do seu contido.");
define("_SCORE","Puntuacin");
define("_USERINFO","Informacin do Usuario");
define("_READREST","Le-lo resto do comentario...");
define("_REPLY","Responder a isto");
define("_REPLYMAIN","Enviar Comentario");
define("_NOSUBJECT","Sen Asunto");
define("_NOANONCOMMENTS","Non se permiten comentarios Annimos, <a href=\"modules.php?name=Your_Account\">rexstrese</a> por favor");
define("_PARENT","Pai");
define("_ROOT","Raz");
define("_UCOMMENT","Comentario");
define("_ALLOWEDHTML","Permitir HTML:");
define("_POSTANON","Envo Annimo");
define("_EXTRANS","Extrans (html tags a texto)");
define("_HTMLFORMATED","Formateado HTML");
define("_PLAINTEXT","Texto Plano");
define("_ONN","en...");
define("_SUBJECT","Asunto");
define("_SURVEYCOM","Enviar Comentario  Enquisa");
define("_SURVEYCOMPRE","Previsualizar Comentario  Enquisa");
define("_NOTRIGHT","Algo non funcionou  pasar unha variable  sa funcin. Esta mensaxe  para manter as cousas no seu sitio");
define("_DIRECTCOM","Comentario directo  Enquisa...");
define("_SENDAMSG","Enviar unha mensaxe");
define("_PASTSURVEYS","Enquisas Pasadas");



define("_LVOTES","Votos");
define("_TOTALVOTES","Votos Totales:");
define("_VOTING","Sala de votacin");
define("_OTHERPOLLS","Outras votacins");
define("_CURRENTSURVEY","Enquisa actual");
define("_CURRENTPOLLRESULTS","Resultados da enquisa actual");
define("_PREVIEW","Vista Previa");
define("_REFRESH","Recargar");
define("_SURVEYS","Enquisas");
define("_ATTACHEDTOARTICLE","- Adxunto  artigo:");
define("_SURVEYSATTACHED","Enquisas Adxuntas a Artigos");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-galego.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","O seu nome");
define("_OK","Aceptar");
define("_COMMENT","comentario");
define("_CONFIGURE","Configurar");
define("_LOGINCREATE","Entrar/Crear Conta");
define("_THRESHOLD","Puntos");
define("_NOCOMMENTS","Sen comentarios");
define("_NESTED","Aniados");
define("_FLAT","Plano");
define("_THREAD","Fo");
define("_OLDEST","Antigos Primeiro");
define("_NEWEST","Novos Primeiro");
define("_HIGHEST","Maior Puntuacin Primeiro");
define("_COMMENTSWARNING","Os comentarios son propiedade de quen os enviou. Non somos responsables do seu contido.");
define("_SCORE","Puntuacin");
define("_USERINFO","Informacin do Usuario");
define("_READREST","Le-lo resto do comentario...");
define("_REPLY","Responder a isto");
define("_REPLYMAIN","Enviar Comentario");
define("_NOSUBJECT","Sen Asunto");
define("_NOANONCOMMENTS","Non se permiten comentarios Annimos, <a href=\"modules.php?name=Your_Account\">rexstrese</a> por favor");
define("_PARENT","Pai");
define("_ROOT","Raz");
define("_UCOMMENT","Comentario");
define("_ALLOWEDHTML","Permitir HTML:");
define("_POSTANON","Envo Annimo");
define("_EXTRANS","Extrans (html tags a texto)");
define("_HTMLFORMATED","Formateado HTML");
define("_PLAINTEXT","Texto Plano");
define("_ONN","en...");
define("_SUBJECT","Asunto");
define("_SURVEYCOM","Enviar Comentario  Enquisa");
define("_SURVEYCOMPRE","Previsualizar Comentario  Enquisa");
define("_NOTRIGHT","Algo non funcionou  pasar unha variable  sa funcin. Esta mensaxe  para manter as cousas no seu sitio");
define("_DIRECTCOM","Comentario directo  Enquisa...");
define("_SENDAMSG","Enviar unha mensaxe");
define("_PASTSURVEYS","Enquisas Pasadas");



define("_LVOTES","Votos");
define("_TOTALVOTES","Votos Totales:");
define("_VOTING","Sala de votacin");
define("_OTHERPOLLS","Outras votacins");
define("_CURRENTSURVEY","Enquisa actual");
define("_CURRENTPOLLRESULTS","Resultados da enquisa actual");
define("_PREVIEW","Vista Previa");
define("_REFRESH","Recargar");
define("_SURVEYS","Enquisas");
define("_ATTACHEDTOARTICLE","- Adxunto  artigo:");
define("_SURVEYSATTACHED","Enquisas Adxuntas a Artigos");

?>
